@@ -1,11 +1,10 @@
-package require Tk 8.6
 source [file join [file dirname [info script]] sprites_light.tcl]
 
 namespace eval ttk::theme::sv_light {
-  package provide ttk::theme::sv_light 2.0
+  package provide ttk::theme::sv_light 2.4
 
   array set theme_colors {
-    -fg      "#000000"
+    -fg      "#1c1c1c"
     -bg      "#fafafa"
     -disfg   "#a0a0a0"
     -selfg   "#ffffff"
@@ -35,7 +34,7 @@ namespace eval ttk::theme::sv_light {
       }
     }
 
-    ttk::style configure TButton -padding {8 4} -anchor center -foreground $theme_colors(-fg)
+    ttk::style configure TButton -padding {8 2 8 3} -anchor center -foreground $theme_colors(-fg) -width 12
     ttk::style map TButton -foreground [list disabled "#a2a2a2" pressed "#636363" active "#1a1a1a"]
     
     ttk::style element create Button.button image \
@@ -58,7 +57,7 @@ namespace eval ttk::theme::sv_light {
       }
     }
 
-    ttk::style configure Toolbutton -padding {8 4} -anchor center
+    ttk::style configure Toolbutton -padding {8 2 8 3} -anchor center -width 12
     
     ttk::style element create Toolbutton.button image \
       [list $I(empty) \
@@ -78,7 +77,7 @@ namespace eval ttk::theme::sv_light {
       }
     }
 
-    ttk::style configure Accent.TButton -padding {8 4} -anchor center -foreground "#ffffff"
+    ttk::style configure Accent.TButton -padding {8 2 8 3} -anchor center -foreground "#ffffff"
     ttk::style map Accent.TButton -foreground [list pressed "#c1d8ee" disabled "#ffffff"]
 
     ttk::style element create AccentButton.button image \
@@ -102,7 +101,7 @@ namespace eval ttk::theme::sv_light {
       }
     }
 
-    ttk::style configure TMenubutton -padding {8 4 10 4}
+    ttk::style configure TMenubutton -padding {8 2 13 3} -width 10
 
     ttk::style element create Menubutton.button image \
       [list $I(button-rest) \
@@ -125,7 +124,7 @@ namespace eval ttk::theme::sv_light {
       }
     }
     
-    ttk::style configure TOptionMenu -padding {8 4 10 4}
+    ttk::style configure TOptionMenu -padding {8 2 13 3} -width 10
 
     ttk::style element create OptionMenu.button image \
       [list $I(button-rest) \
@@ -148,7 +147,7 @@ namespace eval ttk::theme::sv_light {
       }
     }
 
-    ttk::style configure TCheckbutton -padding 4
+    ttk::style configure TCheckbutton -padding 4 -width 10
 
     ttk::style element create Checkbutton.indicator image \
       [list $I(check-unsel-rest) \
@@ -205,7 +204,7 @@ namespace eval ttk::theme::sv_light {
       }
     }
 
-    ttk::style configure Toggle.TButton -padding {8 4 8 4} -anchor center -foreground $theme_colors(-fg)
+    ttk::style configure Toggle.TButton -padding {8 2 8 3} -anchor center -foreground $theme_colors(-fg)
 
     ttk::style map Toggle.TButton -foreground \
       [list {selected disabled} "#ffffff" \
@@ -241,7 +240,7 @@ namespace eval ttk::theme::sv_light {
       }
     }
 
-    ttk::style configure TRadiobutton -padding 4
+    ttk::style configure TRadiobutton -padding 4 -width 10
 
     ttk::style element create Radiobutton.indicator image \
       [list $I(radio-unsel-rest) \
@@ -259,8 +258,8 @@ namespace eval ttk::theme::sv_light {
       ] -width 26 -sticky w
 
     # Entry
-    ttk::style configure TEntry -foreground $theme_colors(-fg)
-    ttk::style map TEntry -foreground [list disabled "#0a0a0a" pressed "#636363" active "#626262"]
+    ttk::style configure TEntry -foreground $theme_colors(-fg) -padding {6 1 4 2}
+    ttk::style map TEntry -foreground [list disabled $theme_colors(-disfg) pressed "#636363" active "#626262"]
 
     ttk::style element create Entry.field image \
       [list $I(textbox-rest) \
@@ -269,7 +268,7 @@ namespace eval ttk::theme::sv_light {
         disabled $I(textbox-dis) \
         {focus !invalid} $I(textbox-focus) \
         hover $I(textbox-hover) \
-      ] -border 5 -padding 8 -sticky nsew
+      ] -border 5 -sticky nsew
 
     # Combobox
     ttk::style layout TCombobox {
@@ -280,10 +279,10 @@ namespace eval ttk::theme::sv_light {
         }
       }
     }
-        
-    ttk::style configure TCombobox -foreground $theme_colors(-fg)
+
+    ttk::style configure TCombobox -foreground $theme_colors(-fg) -padding {6 1 0 2}
     ttk::style configure ComboboxPopdownFrame -borderwidth 1 -relief solid
-    ttk::style map TCombobox -foreground [list disabled "#0a0a0a" pressed "#636363" active "#626262"]
+    ttk::style map TCombobox -foreground [list disabled $theme_colors(-disfg) pressed "#636363" active "#626262"]
     
     ttk::style map TCombobox -selectbackground [list \
       {readonly hover} $theme_colors(-selbg) \
@@ -306,8 +305,8 @@ namespace eval ttk::theme::sv_light {
         focus $I(textbox-focus) \
         {focus !invalid} $I(textbox-focus) \
         hover $I(textbox-hover) \
-      ] -border 5 -padding {8 8 2 8}
-        
+      ] -border 5
+
     ttk::style element create Combobox.arrow image $I(down) -width 34 -sticky {}
 
     # Spinbox
@@ -321,8 +320,8 @@ namespace eval ttk::theme::sv_light {
       }
     }
 
-    ttk::style configure TSpinbox -foreground $theme_colors(-fg)
-    ttk::style map TSpinbox -foreground [list disabled "#0a0a0a" pressed "#636363" active "#626262"]
+    ttk::style configure TSpinbox -foreground $theme_colors(-fg) -padding {6 1 0 2}
+    ttk::style map TSpinbox -foreground [list disabled $theme_colors(-disfg) pressed "#636363" active "#626262"]
 
     ttk::style element create Spinbox.field image \
       [list $I(textbox-rest) \
@@ -332,7 +331,7 @@ namespace eval ttk::theme::sv_light {
         focus $I(textbox-focus) \
         {focus !invalid} $I(textbox-focus) \
         hover $I(textbox-hover) \
-      ] -border 5 -padding {8 8 2 8} -sticky nsew
+      ] -border 5 -sticky nsew
 
     ttk::style element create Spinbox.uparrow image $I(up) -width 34 -height 16 -sticky {}
     ttk::style element create Spinbox.downarrow image $I(down) -width 34 -height 16 -sticky {}
@@ -414,6 +413,7 @@ namespace eval ttk::theme::sv_light {
     }
 
     ttk::style element create Labelframe.border image $I(card) -border 5 -padding 4 -sticky nsew
+    ttk::style configure TLabelframe.Label -font SunValleyBodyStrongFont -foreground "#676767"
 
     # Notebook
     ttk::style layout TNotebook {
@@ -433,9 +433,12 @@ namespace eval ttk::theme::sv_light {
       ] -border 13 -padding {16 14 16 6} -height 32
 
     # Treeview
-    ttk::style configure Treeview -background $theme_colors(-bg) -rowheight [expr {[font metrics font -linespace] + 2}]
+    ttk::style configure Treeview \
+        -background $theme_colors(-bg) \
+        -rowheight [expr {[font metrics SunValleyBodyFont -linespace] + 4}] \
+        -font SunValleyBodyFont
     ttk::style map Treeview \
-      -background [list selected "#f0f0f0"] \
+      -background [list selected "#e7e7e7"] \
       -foreground [list selected "#191919"]
 
     ttk::style element create Treeview.field image $I(card) -border 5 -width 0 -height 0
